.. _validators:

==========
Validators
==========

The following can be imported from ``django_mysql.validators``.

.. currentmodule:: django_mysql.validators

.. class:: ListMaxLengthValidator

    A subclass of django's :class:`~django.core.validators.MaxLengthValidator`
    with list-specific wording.

.. class:: ListMinLengthValidator

    A subclass of django's :class:`~django.core.validators.MinLengthValidator`
    with list-specific wording.

.. class:: SetMaxLengthValidator

    A subclass of django's :class:`~django.core.validators.MaxLengthValidator`
    with set-specific wording.

.. class:: SetMinLengthValidator

    A subclass of django's :class:`~django.core.validators.MinLengthValidator`
    with set-specific wording.
